@@ -36,7 +36,7 @@
 #include <pulse/xmalloc.h>
 #include <pulse/glib-mainloop.h>
 
-#define HAVE_PULSEAUDIO_DEVICE_MANAGER PA_CHECK_VERSION(0,9,21) // && !defined(__CYGWIN__)
+#define HAVE_PULSEAUDIO_DEVICE_MANAGER PA_CHECK_VERSION(0,9,21)
 #if HAVE_PULSEAUDIO_DEVICE_MANAGER
 #  include <pulse/ext-device-manager.h>
 #endif
@@ -53,6 +53,7 @@ namespace Phonon
 QMutex probeMutex;
 static PulseSupport *s_instance = NULL;
 static bool s_wasShutDown = false;
+static bool s_pulseActive = false;
 
 #ifdef HAVE_PULSEAUDIO
 /***
@@ -143,8 +144,6 @@ class PulseUserData
         QMap<Phonon::CaptureCategory, QMap<int, int> > newCaptureDevicePriorities; // prio, device
 };
 
-static bool s_pulseActive = false;
-
 static pa_glib_mainloop *s_mainloop = NULL;
 static pa_context *s_context = NULL;
 
@@ -820,7 +819,9 @@ void PulseSupport::debug()
 }
 
 PulseSupport::PulseSupport()
- : QObject(), mEnabled(false)
+    : QObject()
+    , mEnabled(false)
+    , m_requested(false)
 {
 #ifdef HAVE_PULSEAUDIO
 
@@ -928,15 +929,36 @@ void PulseSupport::connectToDaemon()
 bool PulseSupport::isActive()
 {
 #ifdef HAVE_PULSEAUDIO
-    return mEnabled && s_pulseActive;
+    return mEnabled && isUsed();
 #else
     return false;
 #endif
 }
 
+bool PulseSupport::isUsed()
+{
+   return isRequested() && isUsable();
+}
+
+bool PulseSupport::isUsable() const
+{
+    return s_pulseActive;
+}
+
+bool PulseSupport::isRequested() const
+{
+    return m_requested;
+}
+
+void PulseSupport::request(bool requested)
+{
+    m_requested = requested;
+}
+
 void PulseSupport::enable(bool enabled)
 {
     mEnabled = enabled;
+    request(enabled); // compat, enable needs to imply request.
 #ifdef HAVE_PULSEAUDIO
     logMessage(QString::fromLocal8Bit("Enabled Breakdown: mEnabled: %1, s_pulseActive %2").arg(mEnabled ? "Yes" : "No" ).arg(s_pulseActive ? "Yes" : "No"));
 #endif
@@ -1271,7 +1293,7 @@ void PulseSupport::setupStreamEnvironment(QString streamUuid)
 
 void PulseSupport::emitObjectDescriptionChanged(ObjectDescriptionType type)
 {
-    if (mEnabled)
+    if (isUsed())
         emit objectDescriptionChanged(type);
 }
 
